@@ -20,7 +20,7 @@ logger = logging.getLogger(__name__)
 
 HAS_UPLOADER = False
 
-if os.environ.get("SHOW_ERRORS", None):
+if os.environ.get("SHOW_ERRORS"):
     # local img.show for errors.
     HAS_UPLOADER = True
 
@@ -208,12 +208,11 @@ class PillowLeakTestCase:
             #     ru_maxrss
             # This is the maximum resident set size utilized (in bytes).
             return mem / 1024  # Kb
-        else:
-            # linux
-            # man 2 getrusage
-            #        ru_maxrss (since Linux 2.6.32)
-            #  This is the maximum resident set size used (in kilobytes).
-            return mem  # Kb
+        # linux
+        # man 2 getrusage
+        #        ru_maxrss (since Linux 2.6.32)
+        #  This is the maximum resident set size used (in kilobytes).
+        return mem  # Kb
 
     def _test_leak(self, core):
         start_mem = self._get_mem_usage()
@@ -272,7 +271,7 @@ def netpbm_available():
 
 def magick_command():
     if sys.platform == "win32":
-        magickhome = os.environ.get("MAGICK_HOME", "")
+        magickhome = os.environ.get("MAGICK_HOME")
         if magickhome:
             imagemagick = [os.path.join(magickhome, "convert.exe")]
             graphicsmagick = [os.path.join(magickhome, "gm.exe"), "convert"]
@@ -285,7 +284,7 @@ def magick_command():
 
     if imagemagick and shutil.which(imagemagick[0]):
         return imagemagick
-    elif graphicsmagick and shutil.which(graphicsmagick[0]):
+    if graphicsmagick and shutil.which(graphicsmagick[0]):
         return graphicsmagick
 
 
