@@ -36,7 +36,8 @@ def test_unclosed_file():
         im = Image.open(static_test_file)
         im.load()
 
-    pytest.warns(ResourceWarning, open)
+    with pytest.warns(ResourceWarning):
+        open()
 
 
 def test_closed_file():
@@ -64,7 +65,6 @@ def test_context_manager():
 def test_tell():
     # Arrange
     with Image.open(static_test_file) as im:
-
         # Act
         frame = im.tell()
 
@@ -110,7 +110,6 @@ def test_eoferror():
 
 def test_seek_tell():
     with Image.open(animated_test_file) as im:
-
         layer_number = im.tell()
         assert layer_number == 0
 
