@@ -36,7 +36,8 @@ def test_unclosed_file():
         im = Image.open(TEST_GIF)
         im.load()
 
-    pytest.warns(ResourceWarning, open)
+    with pytest.warns(ResourceWarning):
+        open()
 
 
 def test_closed_file():
@@ -158,39 +159,42 @@ def test_optimize():
     assert test_bilevel(1) == 799
 
 
-def test_optimize_correctness():
-    # 256 color Palette image, posterize to > 128 and < 128 levels
-    # Size bigger and smaller than 512x512
+@pytest.mark.parametrize(
+    "colors, size, expected_palette_length",
+    (
+        # These do optimize the palette
+        (256, 511, 256),
+        (255, 511, 255),
+        (129, 511, 129),
+        (128, 511, 128),
+        (64, 511, 64),
+        (4, 511, 4),
+        # These don't optimize the palette
+        (128, 513, 256),
+        (64, 513, 256),
+        (4, 513, 256),
+    ),
+)
+def test_optimize_correctness(colors, size, expected_palette_length):
+    # 256 color Palette image, posterize to > 128 and < 128 levels.
+    # Size bigger and smaller than 512x512.
     # Check the palette for number of colors allocated.
-    # Check for correctness after conversion back to RGB
-    def check(colors, size, expected_palette_length):
-        # make an image with empty colors in the start of the palette range
-        im = Image.frombytes(
-            "P", (colors, colors), bytes(range(256 - colors, 256)) * colors
-        )
-        im = im.resize((size, size))
-        outfile = BytesIO()
-        im.save(outfile, "GIF")
-        outfile.seek(0)
-        with Image.open(outfile) as reloaded:
-            # check palette length
-            palette_length = max(i + 1 for i, v in enumerate(reloaded.histogram()) if v)
-            assert expected_palette_length == palette_length
+    # Check for correctness after conversion back to RGB.
 
-            assert_image_equal(im.convert("RGB"), reloaded.convert("RGB"))
+    # make an image with empty colors in the start of the palette range
+    im = Image.frombytes(
+        "P", (colors, colors), bytes(range(256 - colors, 256)) * colors
+    )
+    im = im.resize((size, size))
+    outfile = BytesIO()
+    im.save(outfile, "GIF")
+    outfile.seek(0)
+    with Image.open(outfile) as reloaded:
+        # check palette length
+        palette_length = max(i + 1 for i, v in enumerate(reloaded.histogram()) if v)
+        assert expected_palette_length == palette_length
 
-    # These do optimize the palette
-    check(256, 511, 256)
-    check(255, 511, 255)
-    check(129, 511, 129)
-    check(128, 511, 128)
-    check(64, 511, 64)
-    check(4, 511, 4)
-
-    # These don't optimize the palette
-    check(128, 513, 256)
-    check(64, 513, 256)
-    check(4, 513, 256)
+        assert_image_equal(im.convert("RGB"), reloaded.convert("RGB"))
 
 
 def test_optimize_full_l():
@@ -206,7 +210,7 @@ def test_optimize_if_palette_can_be_reduced_by_half():
         im = im.resize((591, 443))
     im_rgb = im.convert("RGB")
 
-    for (optimize, colors) in ((False, 256), (True, 8)):
+    for optimize, colors in ((False, 256), (True, 8)):
         out = BytesIO()
         im_rgb.save(out, "GIF", optimize=optimize)
         with Image.open(out) as reloaded:
@@ -218,7 +222,6 @@ def test_roundtrip(tmp_path):
     im = hopper()
     im.save(out)
     with Image.open(out) as reread:
-
         assert_image_similar(reread.convert("RGB"), im, 50)
 
 
@@ -229,7 +232,6 @@ def test_roundtrip2(tmp_path):
         im2 = im.copy()
         im2.save(out)
     with Image.open(out) as reread:
-
         assert_image_similar(reread.convert("RGB"), hopper(), 50)
 
 
@@ -239,7 +241,6 @@ def test_roundtrip_save_all(tmp_path):
     im = hopper()
     im.save(out, save_all=True)
     with Image.open(out) as reread:
-
         assert_image_similar(reread.convert("RGB"), im, 50)
 
     # Multiframe image
@@ -281,13 +282,11 @@ def test_headers_saving_for_animated_gifs(tmp_path):
     important_headers = ["background", "version", "duration", "loop"]
     # Multiframe image
     with Image.open("Tests/images/dispose_bgnd.gif") as im:
-
         info = im.info.copy()
 
         out = str(tmp_path / "temp.gif")
         im.save(out, save_all=True)
     with Image.open(out) as reread:
-
         for header in important_headers:
             assert info[header] == reread.info[header]
 
@@ -305,7 +304,6 @@ def test_palette_handling(tmp_path):
         im2.save(f, optimize=True)
 
     with Image.open(f) as reloaded:
-
         assert_image_similar(im, reloaded.convert("RGB"), 10)
 
 
@@ -321,7 +319,6 @@ def test_palette_434(tmp_path):
 
     orig = "Tests/images/test.colors.gif"
     with Image.open(orig) as im:
-
         with roundtrip(im) as reloaded:
             assert_image_similar(im, reloaded, 1)
         with roundtrip(im, optimize=True) as reloaded:
@@ -572,7 +569,6 @@ def test_save_dispose(tmp_path):
     )
 
     with Image.open(out) as img:
-
         for i in range(2):
             img.seek(img.tell() + 1)
             assert img.disposal_method == i + 1
@@ -677,6 +673,24 @@ def test_dispose2_background(tmp_path):
         assert im.getpixel((0, 0)) == (255, 0, 0)
 
 
+def test_dispose2_background_frame(tmp_path):
+    out = str(tmp_path / "temp.gif")
+
+    im_list = [Image.new("RGBA", (1, 20))]
+
+    different_frame = Image.new("RGBA", (1, 20))
+    different_frame.putpixel((0, 10), (255, 0, 0, 255))
+    im_list.append(different_frame)
+
+    # Frame that matches the background
+    im_list.append(Image.new("RGBA", (1, 20)))
+
+    im_list[0].save(out, save_all=True, append_images=im_list[1:], disposal=2)
+
+    with Image.open(out) as im:
+        assert im.n_frames == 3
+
+
 def test_transparency_in_second_frame(tmp_path):
     out = str(tmp_path / "temp.gif")
     with Image.open("Tests/images/different_transparency.gif") as im:
@@ -752,7 +766,6 @@ def test_multiple_duration(tmp_path):
         out, save_all=True, append_images=im_list[1:], duration=duration_list
     )
     with Image.open(out) as reread:
-
         for duration in duration_list:
             assert reread.info["duration"] == duration
             try:
@@ -765,7 +778,6 @@ def test_multiple_duration(tmp_path):
         out, save_all=True, append_images=im_list[1:], duration=tuple(duration_list)
     )
     with Image.open(out) as reread:
-
         for duration in duration_list:
             assert reread.info["duration"] == duration
             try:
@@ -791,6 +803,22 @@ def test_roundtrip_info_duration(tmp_path):
         ] == duration_list
 
 
+def test_roundtrip_info_duration_combined(tmp_path):
+    out = str(tmp_path / "temp.gif")
+    with Image.open("Tests/images/duplicate_frame.gif") as im:
+        assert [frame.info["duration"] for frame in ImageSequence.Iterator(im)] == [
+            1000,
+            1000,
+            1000,
+        ]
+        im.save(out, save_all=True)
+
+    with Image.open(out) as reloaded:
+        assert [
+            frame.info["duration"] for frame in ImageSequence.Iterator(reloaded)
+        ] == [1000, 2000]
+
+
 def test_identical_frames(tmp_path):
     duration_list = [1000, 1500, 2000, 4000]
 
@@ -807,7 +835,6 @@ def test_identical_frames(tmp_path):
         out, save_all=True, append_images=im_list[1:], duration=duration_list
     )
     with Image.open(out) as reread:
-
         # Assert that the first three frames were combined
         assert reread.n_frames == 2
 
@@ -859,14 +886,23 @@ def test_background(tmp_path):
     im.info["background"] = 1
     im.save(out)
     with Image.open(out) as reread:
-
         assert reread.info["background"] == im.info["background"]
 
+
+def test_webp_background(tmp_path):
+    out = str(tmp_path / "temp.gif")
+
+    # Test opaque WebP background
     if features.check("webp") and features.check("webp_anim"):
         with Image.open("Tests/images/hopper.webp") as im:
-            assert isinstance(im.info["background"], tuple)
+            assert im.info["background"] == (255, 255, 255, 255)
             im.save(out)
 
+    # Test non-opaque WebP background
+    im = Image.new("L", (100, 100), "#000")
+    im.info["background"] = (0, 0, 0, 0)
+    im.save(out)
+
 
 def test_comment(tmp_path):
     with Image.open(TEST_GIF) as im:
@@ -1052,7 +1088,8 @@ def test_rgb_transparency(tmp_path):
     im = Image.new("RGB", (1, 1))
     im.info["transparency"] = b""
     ims = [Image.new("RGB", (1, 1))]
-    pytest.warns(UserWarning, im.save, out, save_all=True, append_images=ims)
+    with pytest.warns(UserWarning):
+        im.save(out, save_all=True, append_images=ims)
 
     with Image.open(out) as reloaded:
         assert "transparency" not in reloaded.info
