@@ -42,7 +42,8 @@ def test_unclosed_file():
         im = Image.open(test_files[0])
         im.load()
 
-    pytest.warns(ResourceWarning, open)
+    with pytest.warns(ResourceWarning):
+        open()
 
 
 def test_closed_file():
@@ -80,7 +81,10 @@ def test_app(test_file):
 
 @pytest.mark.parametrize("test_file", test_files)
 def test_exif(test_file):
-    with Image.open(test_file) as im:
+    with Image.open(test_file) as im_original:
+        im_reloaded = roundtrip(im_original, save_all=True, exif=im_original.getexif())
+
+    for im in (im_original, im_reloaded):
         info = im._getexif()
         assert info[272] == "Nintendo 3DS"
         assert info[296] == 2
@@ -165,8 +169,7 @@ def test_mp_no_data():
 def test_mp_attribute(test_file):
     with Image.open(test_file) as im:
         mpinfo = im._getmp()
-    frame_number = 0
-    for mpentry in mpinfo[0xB002]:
+    for frame_number, mpentry in enumerate(mpinfo[0xB002]):
         mpattr = mpentry["Attribute"]
         if frame_number:
             assert not mpattr["RepresentativeImageFlag"]
@@ -177,7 +180,6 @@ def test_mp_attribute(test_file):
         assert mpattr["ImageDataFormat"] == "JPEG"
         assert mpattr["MPType"] == "Multi-Frame Image: (Disparity)"
         assert mpattr["Reserved"] == 0
-        frame_number += 1
 
 
 @pytest.mark.parametrize("test_file", test_files)
@@ -268,6 +270,7 @@ def test_save_all():
     im_reloaded = roundtrip(im, save_all=True, append_images=[im2])
 
     assert_image_equal(im, im_reloaded)
+    assert im_reloaded.mpinfo[45056] == b"0100"
 
     im_reloaded.seek(1)
     assert_image_similar(im2, im_reloaded, 1)
