@@ -2,17 +2,10 @@ import os.path
 import subprocess
 
 import pytest
+
 from PIL import Image
 
-from .helper import (
-    IMCONVERT,
-    assert_image_equal,
-    hopper,
-    imagemagick_available,
-    skip_known_bad_test,
-)
-
-_roundtrip = imagemagick_available()
+from .helper import assert_image_equal, hopper, magick_command
 
 
 def helper_save_as_palm(tmp_path, mode):
@@ -28,13 +21,10 @@ def helper_save_as_palm(tmp_path, mode):
     assert os.path.getsize(outfile) > 0
 
 
-def open_with_imagemagick(tmp_path, f):
-    if not imagemagick_available():
-        raise OSError()
-
+def open_with_magick(magick, tmp_path, f):
     outfile = str(tmp_path / "temp.png")
     rc = subprocess.call(
-        [IMCONVERT, f, outfile], stdout=subprocess.DEVNULL, stderr=subprocess.STDOUT
+        magick + [f, outfile], stdout=subprocess.DEVNULL, stderr=subprocess.STDOUT
     )
     if rc:
         raise OSError
@@ -42,14 +32,15 @@ def open_with_imagemagick(tmp_path, f):
 
 
 def roundtrip(tmp_path, mode):
-    if not _roundtrip:
+    magick = magick_command()
+    if not magick:
         return
 
     im = hopper(mode)
     outfile = str(tmp_path / "temp.palm")
 
     im.save(outfile)
-    converted = open_with_imagemagick(tmp_path, outfile)
+    converted = open_with_magick(magick, tmp_path, outfile)
     assert_image_equal(converted, im)
 
 
@@ -62,29 +53,17 @@ def test_monochrome(tmp_path):
     roundtrip(tmp_path, mode)
 
 
+@pytest.mark.xfail(reason="Palm P image is wrong")
 def test_p_mode(tmp_path):
     # Arrange
     mode = "P"
 
     # Act / Assert
     helper_save_as_palm(tmp_path, mode)
-    skip_known_bad_test("Palm P image is wrong")
     roundtrip(tmp_path, mode)
 
 
-def test_l_ioerror(tmp_path):
-    # Arrange
-    mode = "L"
-
-    # Act / Assert
-    with pytest.raises(IOError):
-        helper_save_as_palm(tmp_path, mode)
-
-
-def test_rgb_ioerror(tmp_path):
-    # Arrange
-    mode = "RGB"
-
-    # Act / Assert
-    with pytest.raises(IOError):
+@pytest.mark.parametrize("mode", ("L", "RGB"))
+def test_oserror(tmp_path, mode):
+    with pytest.raises(OSError):
         helper_save_as_palm(tmp_path, mode)
