@@ -90,14 +90,14 @@ def test_write_animation_RGB(tmp_path):
             check(temp_file1)
 
             # Tests appending using a generator
-            def imGenerator(ims):
+            def im_generator(ims):
                 yield from ims
 
             temp_file2 = str(tmp_path / "temp_generator.webp")
             frame1.copy().save(
                 temp_file2,
                 save_all=True,
-                append_images=imGenerator([frame2]),
+                append_images=im_generator([frame2]),
                 lossless=True,
             )
             check(temp_file2)
@@ -134,6 +134,18 @@ def test_timestamp_and_duration(tmp_path):
             ts += durations[frame]
 
 
+def test_float_duration(tmp_path):
+    temp_file = str(tmp_path / "temp.webp")
+    with Image.open("Tests/images/iss634.apng") as im:
+        assert im.info["duration"] == 70.0
+
+        im.save(temp_file, save_all=True)
+
+    with Image.open(temp_file) as reloaded:
+        reloaded.load()
+        assert reloaded.info["duration"] == 70
+
+
 def test_seeking(tmp_path):
     """
     Create an animated WebP file, and then try seeking through frames in reverse-order,
