@@ -11,12 +11,15 @@ pytestmark = [
     skip_unless_feature("webp_mux"),
 ]
 
+try:
+    from defusedxml import ElementTree
+except ImportError:
+    ElementTree = None
+
 
 def test_read_exif_metadata():
-
     file_path = "Tests/images/flower.webp"
     with Image.open(file_path) as image:
-
         assert image.format == "WEBP"
         exif_data = image.info.get("exif", None)
         assert exif_data
@@ -59,10 +62,8 @@ def test_write_exif_metadata():
 
 
 def test_read_icc_profile():
-
     file_path = "Tests/images/flower2.webp"
     with Image.open(file_path) as image:
-
         assert image.format == "WEBP"
         assert image.info.get("icc_profile", None)
 
@@ -110,6 +111,22 @@ def test_read_no_exif():
         assert not webp_image._getexif()
 
 
+def test_getxmp():
+    with Image.open("Tests/images/flower.webp") as im:
+        assert "xmp" not in im.info
+        assert im.getxmp() == {}
+
+    with Image.open("Tests/images/flower2.webp") as im:
+        if ElementTree is None:
+            with pytest.warns(UserWarning):
+                assert im.getxmp() == {}
+        else:
+            assert (
+                im.getxmp()["xmpmeta"]["xmptk"]
+                == "Adobe XMP Core 5.3-c011 66.145661, 2012/02/06-14:56:27        "
+            )
+
+
 @skip_unless_feature("webp_anim")
 def test_write_animated_metadata(tmp_path):
     iccp_data = b"<iccp_data>"
