@@ -8,7 +8,6 @@ from PIL import Image, ImagePath
 
 
 def test_path():
-
     p = ImagePath.Path(list(range(10)))
 
     # sequence interface
@@ -58,10 +57,7 @@ def test_path():
     assert list(p) == [(0.0, 1.0)]
 
     arr = array.array("f", [0, 1])
-    if hasattr(arr, "tobytes"):
-        p = ImagePath.Path(arr.tobytes())
-    else:
-        p = ImagePath.Path(arr.tostring())
+    p = ImagePath.Path(arr.tobytes())
     assert list(p) == [(0.0, 1.0)]
 
 
@@ -174,7 +170,7 @@ def test_overflow_segfault():
     # through to the sequence. Seeing this on 32-bit Windows.
     with pytest.raises((TypeError, MemoryError)):
         # post patch, this fails with a memory error
-        x = evil()
+        x = Evil()
 
         # This fails due to the invalid malloc above,
         # and segfaults
@@ -182,7 +178,7 @@ def test_overflow_segfault():
             x[i] = b"0" * 16
 
 
-class evil:
+class Evil:
     def __init__(self):
         self.corrupt = Image.core.path(0x4000000000000000)
 
