@@ -4,7 +4,7 @@ import pytest
 
 from PIL import Image
 
-from .helper import assert_deep_equal, assert_image, hopper
+from .helper import assert_deep_equal, assert_image, hopper, skip_unless_feature
 
 numpy = pytest.importorskip("numpy", reason="NumPy not installed")
 
@@ -34,7 +34,7 @@ def test_numpy_to_image():
 
     # Check supported 1-bit integer formats
     assert_image(to_image(bool, 1, 1), "1", TEST_IMAGE_SIZE)
-    assert_image(to_image(numpy.bool8, 1, 1), "1", TEST_IMAGE_SIZE)
+    assert_image(to_image(numpy.bool_, 1, 1), "1", TEST_IMAGE_SIZE)
 
     # Check supported 8-bit integer formats
     assert_image(to_image(numpy.uint8), "L", TEST_IMAGE_SIZE)
@@ -193,7 +193,7 @@ def test_putdata():
     "dtype",
     (
         bool,
-        numpy.bool8,
+        numpy.bool_,
         numpy.int8,
         numpy.int16,
         numpy.int32,
@@ -219,6 +219,13 @@ def test_zero_size():
     assert im.size == (0, 0)
 
 
+@skip_unless_feature("libtiff")
+def test_load_first():
+    with Image.open("Tests/images/g4_orientation_5.tif") as im:
+        a = numpy.array(im)
+        assert a.shape == (88, 590)
+
+
 def test_bool():
     # https://github.com/python-pillow/Pillow/issues/2044
     a = numpy.zeros((10, 2), dtype=bool)
@@ -235,7 +242,6 @@ def test_no_resource_warning_for_numpy_array():
 
     test_file = "Tests/images/hopper.png"
     with Image.open(test_file) as im:
-
         # Act/Assert
         with warnings.catch_warnings():
             array(im)
