@@ -3,14 +3,14 @@
  * a Python / PIL interface to the littleCMS ICC Color Management System
  * Copyright (C) 2002-2003 Kevin Cazabon
  * kevin@cazabon.com
- * http://www.cazabon.com
+ * https://www.cazabon.com
  * Adapted/reworked for PIL by Fredrik Lundh
  * Copyright (c) 2009 Fredrik Lundh
  * Updated to LCMS2
  * Copyright (c) 2013 Eric Soroos
  *
- * pyCMS home page:  http://www.cazabon.com/pyCMS
- * littleCMS home page:  http://www.littlecms.com
+ * pyCMS home page:  https://www.cazabon.com/pyCMS
+ * littleCMS home page:  https://www.littlecms.com
  * (littleCMS is Copyright (C) 1998-2001 Marti Maria)
  *
  * Originally released under LGPL.  Graciously donated to PIL in
@@ -23,7 +23,7 @@ pyCMS\n\
 a Python / PIL interface to the littleCMS ICC Color Management System\n\
 Copyright (C) 2002-2003 Kevin Cazabon\n\
 kevin@cazabon.com\n\
-http://www.cazabon.com\n\
+https://www.cazabon.com\n\
 "
 
 #define PY_SSIZE_T_CLEAN
@@ -116,7 +116,7 @@ cms_profile_open(PyObject *self, PyObject *args) {
 }
 
 static PyObject *
-cms_profile_fromstring(PyObject *self, PyObject *args) {
+cms_profile_frombytes(PyObject *self, PyObject *args) {
     cmsHPROFILE hProfile;
 
     char *pProfile;
@@ -950,6 +950,8 @@ _is_intent_supported(CmsProfileObject *self, int clut) {
             return Py_None;
         }
         PyDict_SetItem(result, id, entry);
+        Py_DECREF(id);
+        Py_DECREF(entry);
     }
     return result;
 }
@@ -959,25 +961,24 @@ _is_intent_supported(CmsProfileObject *self, int clut) {
 
 static PyMethodDef pyCMSdll_methods[] = {
 
-    {"profile_open", cms_profile_open, 1},
-    {"profile_frombytes", cms_profile_fromstring, 1},
-    {"profile_fromstring", cms_profile_fromstring, 1},
-    {"profile_tobytes", cms_profile_tobytes, 1},
+    {"profile_open", cms_profile_open, METH_VARARGS},
+    {"profile_frombytes", cms_profile_frombytes, METH_VARARGS},
+    {"profile_tobytes", cms_profile_tobytes, METH_VARARGS},
 
     /* profile and transform functions */
-    {"buildTransform", buildTransform, 1},
-    {"buildProofTransform", buildProofTransform, 1},
-    {"createProfile", createProfile, 1},
+    {"buildTransform", buildTransform, METH_VARARGS},
+    {"buildProofTransform", buildProofTransform, METH_VARARGS},
+    {"createProfile", createProfile, METH_VARARGS},
 
 /* platform specific tools */
 #ifdef _WIN32
-    {"get_display_profile_win32", cms_get_display_profile_win32, 1},
+    {"get_display_profile_win32", cms_get_display_profile_win32, METH_VARARGS},
 #endif
 
     {NULL, NULL}};
 
 static struct PyMethodDef cms_profile_methods[] = {
-    {"is_intent_supported", (PyCFunction)cms_profile_is_intent_supported, 1},
+    {"is_intent_supported", (PyCFunction)cms_profile_is_intent_supported, METH_VARARGS},
     {NULL, NULL} /* sentinel */
 };
 
@@ -1532,7 +1533,8 @@ setup_module(PyObject *m) {
     } else {
         v = PyUnicode_FromFormat("%d.%d", vn / 1000, (vn / 10) % 100);
     }
-    PyDict_SetItemString(d, "littlecms_version", v);
+    PyDict_SetItemString(d, "littlecms_version", v ? v : Py_None);
+    Py_XDECREF(v);
 
     return 0;
 }
