@@ -22,7 +22,7 @@
  * See the README file for information on usage and redistribution.
  */
 
-
+#define PY_SSIZE_T_CLEAN
 #include "Python.h"
 
 #include "libImaging/Imaging.h"
@@ -41,15 +41,13 @@
 #endif
 
 typedef struct {
-    PyObject_HEAD
-    ImagingDIB dib;
+    PyObject_HEAD ImagingDIB dib;
 } ImagingDisplayObject;
 
 static PyTypeObject ImagingDisplayType;
 
-static ImagingDisplayObject*
-_new(const char* mode, int xsize, int ysize)
-{
+static ImagingDisplayObject *
+_new(const char *mode, int xsize, int ysize) {
     ImagingDisplayObject *display;
 
     if (PyType_Ready(&ImagingDisplayType) < 0) {
@@ -71,17 +69,15 @@ _new(const char* mode, int xsize, int ysize)
 }
 
 static void
-_delete(ImagingDisplayObject* display)
-{
+_delete(ImagingDisplayObject *display) {
     if (display->dib) {
         ImagingDeleteDIB(display->dib);
     }
     PyObject_Del(display);
 }
 
-static PyObject*
-_expose(ImagingDisplayObject* display, PyObject* args)
-{
+static PyObject *
+_expose(ImagingDisplayObject *display, PyObject *args) {
     HDC hdc;
     if (!PyArg_ParseTuple(args, F_HANDLE, &hdc)) {
         return NULL;
@@ -93,15 +89,23 @@ _expose(ImagingDisplayObject* display, PyObject* args)
     return Py_None;
 }
 
-static PyObject*
-_draw(ImagingDisplayObject* display, PyObject* args)
-{
+static PyObject *
+_draw(ImagingDisplayObject *display, PyObject *args) {
     HDC hdc;
     int dst[4];
     int src[4];
-    if (!PyArg_ParseTuple(args, F_HANDLE "(iiii)(iiii)", &hdc,
-                          dst+0, dst+1, dst+2, dst+3,
-                          src+0, src+1, src+2, src+3)) {
+    if (!PyArg_ParseTuple(
+            args,
+            F_HANDLE "(iiii)(iiii)",
+            &hdc,
+            dst + 0,
+            dst + 1,
+            dst + 2,
+            dst + 3,
+            src + 0,
+            src + 1,
+            src + 2,
+            src + 3)) {
         return NULL;
     }
 
@@ -111,17 +115,17 @@ _draw(ImagingDisplayObject* display, PyObject* args)
     return Py_None;
 }
 
-extern Imaging PyImaging_AsImaging(PyObject *op);
+extern Imaging
+PyImaging_AsImaging(PyObject *op);
 
-static PyObject*
-_paste(ImagingDisplayObject* display, PyObject* args)
-{
+static PyObject *
+_paste(ImagingDisplayObject *display, PyObject *args) {
     Imaging im;
 
-    PyObject* op;
+    PyObject *op;
     int xy[4];
     xy[0] = xy[1] = xy[2] = xy[3] = 0;
-    if (!PyArg_ParseTuple(args, "O|(iiii)", &op, xy+0, xy+1, xy+2, xy+3)) {
+    if (!PyArg_ParseTuple(args, "O|(iiii)", &op, xy + 0, xy + 1, xy + 2, xy + 3)) {
         return NULL;
     }
     im = PyImaging_AsImaging(op);
@@ -142,9 +146,8 @@ _paste(ImagingDisplayObject* display, PyObject* args)
     return Py_None;
 }
 
-static PyObject*
-_query_palette(ImagingDisplayObject* display, PyObject* args)
-{
+static PyObject *
+_query_palette(ImagingDisplayObject *display, PyObject *args) {
     HDC hdc;
     int status;
 
@@ -157,9 +160,8 @@ _query_palette(ImagingDisplayObject* display, PyObject* args)
     return Py_BuildValue("i", status);
 }
 
-static PyObject*
-_getdc(ImagingDisplayObject* display, PyObject* args)
-{
+static PyObject *
+_getdc(ImagingDisplayObject *display, PyObject *args) {
     HWND window;
     HDC dc;
 
@@ -176,9 +178,8 @@ _getdc(ImagingDisplayObject* display, PyObject* args)
     return Py_BuildValue(F_HANDLE, dc);
 }
 
-static PyObject*
-_releasedc(ImagingDisplayObject* display, PyObject* args)
-{
+static PyObject *
+_releasedc(ImagingDisplayObject *display, PyObject *args) {
     HWND window;
     HDC dc;
 
@@ -192,109 +193,98 @@ _releasedc(ImagingDisplayObject* display, PyObject* args)
     return Py_None;
 }
 
-static PyObject*
-_frombytes(ImagingDisplayObject* display, PyObject* args)
-{
-    char* ptr;
-    int bytes;
+static PyObject *
+_frombytes(ImagingDisplayObject *display, PyObject *args) {
+    Py_buffer buffer;
 
-    if (!PyArg_ParseTuple(args, "y#:frombytes", &ptr, &bytes)) {
+    if (!PyArg_ParseTuple(args, "y*:frombytes", &buffer)) {
         return NULL;
     }
 
-    if (display->dib->ysize * display->dib->linesize != bytes) {
+    if (display->dib->ysize * display->dib->linesize != buffer.len) {
+        PyBuffer_Release(&buffer);
         PyErr_SetString(PyExc_ValueError, "wrong size");
         return NULL;
     }
 
-    memcpy(display->dib->bits, ptr, bytes);
+    memcpy(display->dib->bits, buffer.buf, buffer.len);
 
+    PyBuffer_Release(&buffer);
     Py_INCREF(Py_None);
     return Py_None;
 }
 
-static PyObject*
-_tobytes(ImagingDisplayObject* display, PyObject* args)
-{
+static PyObject *
+_tobytes(ImagingDisplayObject *display, PyObject *args) {
     if (!PyArg_ParseTuple(args, ":tobytes")) {
         return NULL;
     }
 
     return PyBytes_FromStringAndSize(
-        display->dib->bits, display->dib->ysize * display->dib->linesize
-        );
+        display->dib->bits, display->dib->ysize * display->dib->linesize);
 }
 
 static struct PyMethodDef methods[] = {
-    {"draw", (PyCFunction)_draw, 1},
-    {"expose", (PyCFunction)_expose, 1},
-    {"paste", (PyCFunction)_paste, 1},
-    {"query_palette", (PyCFunction)_query_palette, 1},
-    {"getdc", (PyCFunction)_getdc, 1},
-    {"releasedc", (PyCFunction)_releasedc, 1},
-    {"frombytes", (PyCFunction)_frombytes, 1},
-    {"tobytes", (PyCFunction)_tobytes, 1},
-    {"fromstring", (PyCFunction)_frombytes, 1},
-    {"tostring", (PyCFunction)_tobytes, 1},
+    {"draw", (PyCFunction)_draw, METH_VARARGS},
+    {"expose", (PyCFunction)_expose, METH_VARARGS},
+    {"paste", (PyCFunction)_paste, METH_VARARGS},
+    {"query_palette", (PyCFunction)_query_palette, METH_VARARGS},
+    {"getdc", (PyCFunction)_getdc, METH_VARARGS},
+    {"releasedc", (PyCFunction)_releasedc, METH_VARARGS},
+    {"frombytes", (PyCFunction)_frombytes, METH_VARARGS},
+    {"tobytes", (PyCFunction)_tobytes, METH_VARARGS},
     {NULL, NULL} /* sentinel */
 };
 
-static PyObject*
-_getattr_mode(ImagingDisplayObject* self, void* closure)
-{
+static PyObject *
+_getattr_mode(ImagingDisplayObject *self, void *closure) {
     return Py_BuildValue("s", self->dib->mode);
 }
 
-static PyObject*
-_getattr_size(ImagingDisplayObject* self, void* closure)
-{
+static PyObject *
+_getattr_size(ImagingDisplayObject *self, void *closure) {
     return Py_BuildValue("ii", self->dib->xsize, self->dib->ysize);
 }
 
 static struct PyGetSetDef getsetters[] = {
-    { "mode",   (getter) _getattr_mode },
-    { "size",   (getter) _getattr_size },
-    { NULL }
-};
+    {"mode", (getter)_getattr_mode}, {"size", (getter)_getattr_size}, {NULL}};
 
 static PyTypeObject ImagingDisplayType = {
-    PyVarObject_HEAD_INIT(NULL, 0)
-    "ImagingDisplay",            /*tp_name*/
-    sizeof(ImagingDisplayObject),/*tp_size*/
-    0,                           /*tp_itemsize*/
+    PyVarObject_HEAD_INIT(NULL, 0) "ImagingDisplay", /*tp_name*/
+    sizeof(ImagingDisplayObject),                    /*tp_size*/
+    0,                                               /*tp_itemsize*/
     /* methods */
-    (destructor)_delete,        /*tp_dealloc*/
-    0,                          /*tp_print*/
-    0,                          /*tp_getattr*/
-    0,                          /*tp_setattr*/
-    0,                          /*tp_compare*/
-    0,                          /*tp_repr*/
-    0,                          /*tp_as_number */
-    0,                          /*tp_as_sequence */
-    0,                          /*tp_as_mapping */
-    0,                          /*tp_hash*/
-    0,                          /*tp_call*/
-    0,                          /*tp_str*/
-    0,                          /*tp_getattro*/
-    0,                          /*tp_setattro*/
-    0,                          /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT,         /*tp_flags*/
-    0,                          /*tp_doc*/
-    0,                          /*tp_traverse*/
-    0,                          /*tp_clear*/
-    0,                          /*tp_richcompare*/
-    0,                          /*tp_weaklistoffset*/
-    0,                          /*tp_iter*/
-    0,                          /*tp_iternext*/
-    methods,                    /*tp_methods*/
-    0,                          /*tp_members*/
-    getsetters,                 /*tp_getset*/
+    (destructor)_delete, /*tp_dealloc*/
+    0,                   /*tp_print*/
+    0,                   /*tp_getattr*/
+    0,                   /*tp_setattr*/
+    0,                   /*tp_compare*/
+    0,                   /*tp_repr*/
+    0,                   /*tp_as_number */
+    0,                   /*tp_as_sequence */
+    0,                   /*tp_as_mapping */
+    0,                   /*tp_hash*/
+    0,                   /*tp_call*/
+    0,                   /*tp_str*/
+    0,                   /*tp_getattro*/
+    0,                   /*tp_setattro*/
+    0,                   /*tp_as_buffer*/
+    Py_TPFLAGS_DEFAULT,  /*tp_flags*/
+    0,                   /*tp_doc*/
+    0,                   /*tp_traverse*/
+    0,                   /*tp_clear*/
+    0,                   /*tp_richcompare*/
+    0,                   /*tp_weaklistoffset*/
+    0,                   /*tp_iter*/
+    0,                   /*tp_iternext*/
+    methods,             /*tp_methods*/
+    0,                   /*tp_members*/
+    getsetters,          /*tp_getset*/
 };
 
-PyObject*
-PyImaging_DisplayWin32(PyObject* self, PyObject* args)
-{
-    ImagingDisplayObject* display;
+PyObject *
+PyImaging_DisplayWin32(PyObject *self, PyObject *args) {
+    ImagingDisplayObject *display;
     char *mode;
     int xsize, ysize;
 
@@ -307,12 +297,11 @@ PyImaging_DisplayWin32(PyObject* self, PyObject* args)
         return NULL;
     }
 
-    return (PyObject*) display;
+    return (PyObject *)display;
 }
 
-PyObject*
-PyImaging_DisplayModeWin32(PyObject* self, PyObject* args)
-{
+PyObject *
+PyImaging_DisplayModeWin32(PyObject *self, PyObject *args) {
     char *mode;
     int size[2];
 
@@ -324,18 +313,17 @@ PyImaging_DisplayModeWin32(PyObject* self, PyObject* args)
 /* -------------------------------------------------------------------- */
 /* Windows screen grabber */
 
-typedef HANDLE(__stdcall* Func_SetThreadDpiAwarenessContext)(HANDLE);
+typedef HANDLE(__stdcall *Func_SetThreadDpiAwarenessContext)(HANDLE);
 
-PyObject*
-PyImaging_GrabScreenWin32(PyObject* self, PyObject* args)
-{
+PyObject *
+PyImaging_GrabScreenWin32(PyObject *self, PyObject *args) {
     int x = 0, y = 0, width, height;
     int includeLayeredWindows = 0, all_screens = 0;
     HBITMAP bitmap;
     BITMAPCOREHEADER core;
     HDC screen, screen_copy;
     DWORD rop;
-    PyObject* buffer;
+    PyObject *buffer;
     HANDLE dpiAwareness;
     HMODULE user32;
     Func_SetThreadDpiAwarenessContext SetThreadDpiAwarenessContext_function;
@@ -354,11 +342,11 @@ PyImaging_GrabScreenWin32(PyObject* self, PyObject* args)
     // loaded dynamically to avoid link errors
     user32 = LoadLibraryA("User32.dll");
     SetThreadDpiAwarenessContext_function =
-            (Func_SetThreadDpiAwarenessContext)
-            GetProcAddress(user32, "SetThreadDpiAwarenessContext");
+        (Func_SetThreadDpiAwarenessContext)GetProcAddress(
+            user32, "SetThreadDpiAwarenessContext");
     if (SetThreadDpiAwarenessContext_function != NULL) {
         // DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE = ((DPI_CONTEXT_HANDLE)-3)
-        dpiAwareness = SetThreadDpiAwarenessContext_function((HANDLE) -3);
+        dpiAwareness = SetThreadDpiAwarenessContext_function((HANDLE)-3);
     }
 
     if (all_screens) {
@@ -398,7 +386,7 @@ PyImaging_GrabScreenWin32(PyObject* self, PyObject* args)
 
     /* step 3: extract bits from bitmap */
 
-    buffer = PyBytes_FromStringAndSize(NULL, height * ((width*3 + 3) & -4));
+    buffer = PyBytes_FromStringAndSize(NULL, height * ((width * 3 + 3) & -4));
     if (!buffer) {
         return NULL;
     }
@@ -408,8 +396,14 @@ PyImaging_GrabScreenWin32(PyObject* self, PyObject* args)
     core.bcHeight = height;
     core.bcPlanes = 1;
     core.bcBitCount = 24;
-    if (!GetDIBits(screen_copy, bitmap, 0, height, PyBytes_AS_STRING(buffer),
-                   (BITMAPINFO*) &core, DIB_RGB_COLORS)) {
+    if (!GetDIBits(
+            screen_copy,
+            bitmap,
+            0,
+            height,
+            PyBytes_AS_STRING(buffer),
+            (BITMAPINFO *)&core,
+            DIB_RGB_COLORS)) {
         goto error;
     }
 
@@ -428,87 +422,19 @@ error:
     return NULL;
 }
 
-static BOOL CALLBACK list_windows_callback(HWND hwnd, LPARAM lParam)
-{
-    PyObject* window_list = (PyObject*) lParam;
-    PyObject* item;
-    PyObject* title;
-    RECT inner, outer;
-    int title_size;
-    int status;
-
-    /* get window title */
-    title_size = GetWindowTextLength(hwnd);
-    if (title_size > 0) {
-        title = PyUnicode_FromStringAndSize(NULL, title_size);
-        if (title) {
-            GetWindowTextW(hwnd, PyUnicode_AS_UNICODE(title), title_size+1);
-        }
-    } else {
-        title = PyUnicode_FromString("");
-    }
-    if (!title) {
-        return 0;
-    }
-
-    /* get bounding boxes */
-    GetClientRect(hwnd, &inner);
-    GetWindowRect(hwnd, &outer);
-
-    item = Py_BuildValue(
-        F_HANDLE "N(iiii)(iiii)", hwnd, title,
-        inner.left, inner.top, inner.right, inner.bottom,
-        outer.left, outer.top, outer.right, outer.bottom
-        );
-    if (!item) {
-        return 0;
-    }
-
-    status = PyList_Append(window_list, item);
-
-    Py_DECREF(item);
-
-    if (status < 0) {
-        return 0;
-    }
-
-    return 1;
-}
-
-PyObject*
-PyImaging_ListWindowsWin32(PyObject* self, PyObject* args)
-{
-    PyObject* window_list;
-
-    window_list = PyList_New(0);
-    if (!window_list) {
-        return NULL;
-    }
-
-    EnumWindows(list_windows_callback, (LPARAM) window_list);
-
-    if (PyErr_Occurred()) {
-        Py_DECREF(window_list);
-        return NULL;
-    }
-
-    return window_list;
-}
-
 /* -------------------------------------------------------------------- */
 /* Windows clipboard grabber */
 
-PyObject*
-PyImaging_GrabClipboardWin32(PyObject* self, PyObject* args)
-{
+PyObject *
+PyImaging_GrabClipboardWin32(PyObject *self, PyObject *args) {
     int clip;
     HANDLE handle = NULL;
     int size;
-    void* data;
-    PyObject* result;
+    void *data;
+    PyObject *result;
     UINT format;
-    UINT formats[] = { CF_DIB, CF_DIBV5, CF_HDROP, RegisterClipboardFormatA("PNG"), 0 };
-    LPCSTR format_names[] = { "DIB", "DIB", "file", "png", NULL };
+    UINT formats[] = {CF_DIB, CF_DIBV5, CF_HDROP, RegisterClipboardFormatA("PNG"), 0};
+    LPCSTR format_names[] = {"DIB", "DIB", "file", "png", NULL};
 
     if (!OpenClipboard(NULL)) {
         PyErr_SetString(PyExc_OSError, "failed to open clipboard");
@@ -553,15 +479,14 @@ PyImaging_GrabClipboardWin32(PyObject* self, PyObject* args)
 static int mainloop = 0;
 
 static void
-callback_error(const char* handler)
-{
-    PyObject* sys_stderr;
+callback_error(const char *handler) {
+    PyObject *sys_stderr;
 
     sys_stderr = PySys_GetObject("stderr");
 
     if (sys_stderr) {
         PyFile_WriteString("*** ImageWin: error in ", sys_stderr);
-        PyFile_WriteString((char*) handler, sys_stderr);
+        PyFile_WriteString((char *)handler, sys_stderr);
         PyFile_WriteString(":\n", sys_stderr);
     }
 
@@ -570,109 +495,119 @@ callback_error(const char* handler)
 }
 
 static LRESULT CALLBACK
-windowCallback(HWND wnd, UINT message, WPARAM wParam, LPARAM lParam)
-{
+windowCallback(HWND wnd, UINT message, WPARAM wParam, LPARAM lParam) {
     PAINTSTRUCT ps;
-    PyObject* callback = NULL;
-    PyObject* result;
-    PyThreadState* threadstate;
-    PyThreadState* current_threadstate;
+    PyObject *callback = NULL;
+    PyObject *result;
+    PyThreadState *threadstate;
+    PyThreadState *current_threadstate;
     HDC dc;
     RECT rect;
     LRESULT status = 0;
 
     /* set up threadstate for messages that calls back into python */
     switch (message) {
-    case WM_CREATE:
-        mainloop++;
-        break;
-    case WM_DESTROY:
-        mainloop--;
-        /* fall through... */
-    case WM_PAINT:
-    case WM_SIZE:
-        callback = (PyObject*) GetWindowLongPtr(wnd, 0);
-        if (callback) {
-            threadstate = (PyThreadState*)
-                GetWindowLongPtr(wnd, sizeof(PyObject*));
-            current_threadstate = PyThreadState_Swap(NULL);
-            PyEval_RestoreThread(threadstate);
-        } else {
-            return DefWindowProc(wnd, message, wParam, lParam);
-        }
+        case WM_CREATE:
+            mainloop++;
+            break;
+        case WM_DESTROY:
+            mainloop--;
+            /* fall through... */
+        case WM_PAINT:
+        case WM_SIZE:
+            callback = (PyObject *)GetWindowLongPtr(wnd, 0);
+            if (callback) {
+                threadstate =
+                    (PyThreadState *)GetWindowLongPtr(wnd, sizeof(PyObject *));
+                current_threadstate = PyThreadState_Swap(NULL);
+                PyEval_RestoreThread(threadstate);
+            } else {
+                return DefWindowProc(wnd, message, wParam, lParam);
+            }
     }
 
     /* process message */
     switch (message) {
+        case WM_PAINT:
+            /* redraw (part of) window.  this generates a WCK-style
+               damage/clear/repair cascade */
+            BeginPaint(wnd, &ps);
+            dc = GetDC(wnd);
+            GetWindowRect(wnd, &rect); /* in screen coordinates */
 
-    case WM_PAINT:
-        /* redraw (part of) window.  this generates a WCK-style
-           damage/clear/repair cascade */
-        BeginPaint(wnd, &ps);
-        dc = GetDC(wnd);
-        GetWindowRect(wnd, &rect); /* in screen coordinates */
+            result = PyObject_CallFunction(
+                callback,
+                "siiii",
+                "damage",
+                ps.rcPaint.left,
+                ps.rcPaint.top,
+                ps.rcPaint.right,
+                ps.rcPaint.bottom);
+            if (result) {
+                Py_DECREF(result);
+            } else {
+                callback_error("window damage callback");
+            }
 
-        result = PyObject_CallFunction(
-            callback, "siiii", "damage",
-            ps.rcPaint.left, ps.rcPaint.top,
-            ps.rcPaint.right, ps.rcPaint.bottom
-            );
-        if (result) {
-            Py_DECREF(result);
-        } else {
-            callback_error("window damage callback");
-        }
+            result = PyObject_CallFunction(
+                callback,
+                "s" F_HANDLE "iiii",
+                "clear",
+                dc,
+                0,
+                0,
+                rect.right - rect.left,
+                rect.bottom - rect.top);
+            if (result) {
+                Py_DECREF(result);
+            } else {
+                callback_error("window clear callback");
+            }
 
-        result = PyObject_CallFunction(
-            callback, "s" F_HANDLE "iiii", "clear", dc,
-            0, 0, rect.right-rect.left, rect.bottom-rect.top
-            );
-        if (result) {
-            Py_DECREF(result);
-        } else {
-            callback_error("window clear callback");
-        }
+            result = PyObject_CallFunction(
+                callback,
+                "s" F_HANDLE "iiii",
+                "repair",
+                dc,
+                0,
+                0,
+                rect.right - rect.left,
+                rect.bottom - rect.top);
+            if (result) {
+                Py_DECREF(result);
+            } else {
+                callback_error("window repair callback");
+            }
 
-        result = PyObject_CallFunction(
-            callback, "s" F_HANDLE "iiii", "repair", dc,
-            0, 0, rect.right-rect.left, rect.bottom-rect.top
-            );
-        if (result) {
-            Py_DECREF(result);
-        } else {
-            callback_error("window repair callback");
-        }
+            ReleaseDC(wnd, dc);
+            EndPaint(wnd, &ps);
+            break;
 
-        ReleaseDC(wnd, dc);
-        EndPaint(wnd, &ps);
-        break;
+        case WM_SIZE:
+            /* resize window */
+            result = PyObject_CallFunction(
+                callback, "sii", "resize", LOWORD(lParam), HIWORD(lParam));
+            if (result) {
+                InvalidateRect(wnd, NULL, 1);
+                Py_DECREF(result);
+            } else {
+                callback_error("window resize callback");
+            }
+            break;
 
-    case WM_SIZE:
-        /* resize window */
-        result = PyObject_CallFunction(
-            callback, "sii", "resize", LOWORD(lParam), HIWORD(lParam)
-            );
-        if (result) {
-            InvalidateRect(wnd, NULL, 1);
-            Py_DECREF(result);
-        } else {
-            callback_error("window resize callback");
-        }
-        break;
+        case WM_DESTROY:
+            /* destroy window */
+            result = PyObject_CallFunction(callback, "s", "destroy");
+            if (result) {
+                Py_DECREF(result);
+            } else {
+                callback_error("window destroy callback");
+            }
+            Py_DECREF(callback);
+            break;
 
-    case WM_DESTROY:
-        /* destroy window */
-        result = PyObject_CallFunction(callback, "s", "destroy");
-        if (result) {
-            Py_DECREF(result);
-        } else {
-            callback_error("window destroy callback");
-        }
-        Py_DECREF(callback);
-        break;
-
-    default:
-        status = DefWindowProc(wnd, message, wParam, lParam);
+        default:
+            status = DefWindowProc(wnd, message, wParam, lParam);
     }
 
     if (callback) {
@@ -684,14 +619,13 @@ windowCallback(HWND wnd, UINT message, WPARAM wParam, LPARAM lParam)
     return status;
 }
 
-PyObject*
-PyImaging_CreateWindowWin32(PyObject* self, PyObject* args)
-{
+PyObject *
+PyImaging_CreateWindowWin32(PyObject *self, PyObject *args) {
     HWND wnd;
     WNDCLASS windowClass;
 
-    char* title;
-    PyObject* callback;
+    char *title;
+    PyObject *callback;
     int width = 0, height = 0;
     if (!PyArg_ParseTuple(args, "sO|ii", &title, &callback, &width, &height)) {
         return NULL;
@@ -707,7 +641,7 @@ PyImaging_CreateWindowWin32(PyObject* self, PyObject* args)
     /* register toplevel window class */
     windowClass.style = CS_CLASSDC;
     windowClass.cbClsExtra = 0;
-    windowClass.cbWndExtra = sizeof(PyObject*) + sizeof(PyThreadState*);
+    windowClass.cbWndExtra = sizeof(PyObject *) + sizeof(PyThreadState *);
     windowClass.hInstance = GetModuleHandle(NULL);
     /* windowClass.hbrBackground = (HBRUSH) (COLOR_BTNFACE + 1); */
     windowClass.hbrBackground = NULL;
@@ -720,11 +654,18 @@ PyImaging_CreateWindowWin32(PyObject* self, PyObject* args)
     RegisterClass(&windowClass); /* FIXME: check return status */
 
     wnd = CreateWindowEx(
-        0, windowClass.lpszClassName, title,
+        0,
+        windowClass.lpszClassName,
+        title,
         WS_OVERLAPPEDWINDOW,
-        CW_USEDEFAULT, CW_USEDEFAULT, width, height,
-        HWND_DESKTOP, NULL, NULL, NULL
-        );
+        CW_USEDEFAULT,
+        CW_USEDEFAULT,
+        width,
+        height,
+        HWND_DESKTOP,
+        NULL,
+        NULL,
+        NULL);
 
     if (!wnd) {
         PyErr_SetString(PyExc_OSError, "failed to create window");
@@ -733,76 +674,76 @@ PyImaging_CreateWindowWin32(PyObject* self, PyObject* args)
 
     /* register window callback */
     Py_INCREF(callback);
-    SetWindowLongPtr(wnd, 0, (LONG_PTR) callback);
-    SetWindowLongPtr(wnd, sizeof(callback), (LONG_PTR) PyThreadState_Get());
+    SetWindowLongPtr(wnd, 0, (LONG_PTR)callback);
+    SetWindowLongPtr(wnd, sizeof(callback), (LONG_PTR)PyThreadState_Get());
 
-    Py_BEGIN_ALLOW_THREADS
-    ShowWindow(wnd, SW_SHOWNORMAL);
+    Py_BEGIN_ALLOW_THREADS ShowWindow(wnd, SW_SHOWNORMAL);
     SetForegroundWindow(wnd); /* to make sure it's visible */
     Py_END_ALLOW_THREADS
 
-    return Py_BuildValue(F_HANDLE, wnd);
+        return Py_BuildValue(F_HANDLE, wnd);
 }
 
-PyObject*
-PyImaging_EventLoopWin32(PyObject* self, PyObject* args)
-{
+PyObject *
+PyImaging_EventLoopWin32(PyObject *self, PyObject *args) {
     MSG msg;
 
-    Py_BEGIN_ALLOW_THREADS
-    while (mainloop && GetMessage(&msg, NULL, 0, 0)) {
+    Py_BEGIN_ALLOW_THREADS while (mainloop && GetMessage(&msg, NULL, 0, 0)) {
         TranslateMessage(&msg);
         DispatchMessage(&msg);
     }
     Py_END_ALLOW_THREADS
 
-    Py_INCREF(Py_None);
+        Py_INCREF(Py_None);
     return Py_None;
 }
 
 /* -------------------------------------------------------------------- */
 /* windows WMF renderer */
 
-#define GET32(p,o) ((DWORD*)(p+o))[0]
+#define GET32(p, o) ((DWORD *)(p + o))[0]
 
 PyObject *
-PyImaging_DrawWmf(PyObject* self, PyObject* args)
-{
+PyImaging_DrawWmf(PyObject *self, PyObject *args) {
     HBITMAP bitmap;
     HENHMETAFILE meta;
     BITMAPCOREHEADER core;
     HDC dc;
     RECT rect;
-    PyObject* buffer = NULL;
-    char* ptr;
+    PyObject *buffer = NULL;
+    char *ptr;
 
-    char* data;
-    int datasize;
+    char *data;
+    Py_ssize_t datasize;
     int width, height;
     int x0, y0, x1, y1;
-    if (!PyArg_ParseTuple(args, "y#(ii)(iiii):_load", &data, &datasize,
-                          &width, &height, &x0, &x1, &y0, &y1)) {
+    if (!PyArg_ParseTuple(
+            args,
+            "y#(ii)(iiii):_load",
+            &data,
+            &datasize,
+            &width,
+            &height,
+            &x0,
+            &x1,
+            &y0,
+            &y1)) {
         return NULL;
     }
 
     /* step 1: copy metafile contents into METAFILE object */
 
     if (datasize > 22 && GET32(data, 0) == 0x9ac6cdd7) {
-
         /* placeable windows metafile (22-byte aldus header) */
-        meta = SetWinMetaFileBits(datasize-22, data+22, NULL, NULL);
-
-    } else if (datasize > 80 && GET32(data, 0) == 1 &&
-               GET32(data, 40) == 0x464d4520) {
+        meta = SetWinMetaFileBits(datasize - 22, data + 22, NULL, NULL);
 
+    } else if (datasize > 80 && GET32(data, 0) == 1 && GET32(data, 40) == 0x464d4520) {
         /* enhanced metafile */
         meta = SetEnhMetaFileBits(datasize, data);
 
     } else {
-
         /* unknown meta format */
         meta = NULL;
-
     }
 
     if (!meta) {
@@ -820,9 +761,7 @@ PyImaging_DrawWmf(PyObject* self, PyObject* args)
 
     dc = CreateCompatibleDC(NULL);
 
-    bitmap = CreateDIBSection(
-        dc, (BITMAPINFO*) &core, DIB_RGB_COLORS, &ptr, NULL, 0
-        );
+    bitmap = CreateDIBSection(dc, (BITMAPINFO *)&core, DIB_RGB_COLORS, &ptr, NULL, 0);
 
     if (!bitmap) {
         PyErr_SetString(PyExc_OSError, "cannot create bitmap");
@@ -852,7 +791,7 @@ PyImaging_DrawWmf(PyObject* self, PyObject* args)
 
     GdiFlush();
 
-    buffer = PyBytes_FromStringAndSize(ptr, height * ((width*3 + 3) & -4));
+    buffer = PyBytes_FromStringAndSize(ptr, height * ((width * 3 + 3) & -4));
 
 error:
     DeleteEnhMetaFile(meta);
@@ -877,18 +816,17 @@ error:
 /* -------------------------------------------------------------------- */
 /* X11 screen grabber */
 
-PyObject*
-PyImaging_GrabScreenX11(PyObject* self, PyObject* args)
-{
+PyObject *
+PyImaging_GrabScreenX11(PyObject *self, PyObject *args) {
     int width, height;
-    char* display_name;
-    xcb_connection_t* connection;
+    char *display_name;
+    xcb_connection_t *connection;
     int screen_number;
     xcb_screen_iterator_t iter;
-    xcb_screen_t* screen = NULL;
-    xcb_get_image_reply_t* reply;
-    xcb_generic_error_t* error;
-    PyObject* buffer = NULL;
+    xcb_screen_t *screen = NULL;
+    xcb_get_image_reply_t *reply;
+    xcb_generic_error_t *error;
+    PyObject *buffer = NULL;
 
     if (!PyArg_ParseTuple(args, "|z", &display_name)) {
         return NULL;
@@ -898,7 +836,10 @@ PyImaging_GrabScreenX11(PyObject* self, PyObject* args)
 
     connection = xcb_connect(display_name, &screen_number);
     if (xcb_connection_has_error(connection)) {
-        PyErr_Format(PyExc_OSError, "X connection failed: error %i", xcb_connection_has_error(connection));
+        PyErr_Format(
+            PyExc_OSError,
+            "X connection failed: error %i",
+            xcb_connection_has_error(connection));
         xcb_disconnect(connection);
         return NULL;
     }
@@ -922,13 +863,26 @@ PyImaging_GrabScreenX11(PyObject* self, PyObject* args)
 
     /* get image data */
 
-    reply = xcb_get_image_reply(connection,
-                                xcb_get_image(connection, XCB_IMAGE_FORMAT_Z_PIXMAP, screen->root,
-                                              0, 0, width, height, 0x00ffffff),
-                                &error);
+    reply = xcb_get_image_reply(
+        connection,
+        xcb_get_image(
+            connection,
+            XCB_IMAGE_FORMAT_Z_PIXMAP,
+            screen->root,
+            0,
+            0,
+            width,
+            height,
+            0x00ffffff),
+        &error);
     if (reply == NULL) {
-        PyErr_Format(PyExc_OSError, "X get_image failed: error %i (%i, %i, %i)",
-                     error->error_code, error->major_code, error->minor_code, error->resource_id);
+        PyErr_Format(
+            PyExc_OSError,
+            "X get_image failed: error %i (%i, %i, %i)",
+            error->error_code,
+            error->major_code,
+            error->minor_code,
+            error->resource_id);
         free(error);
         xcb_disconnect(connection);
         return NULL;
@@ -937,8 +891,8 @@ PyImaging_GrabScreenX11(PyObject* self, PyObject* args)
     /* store data in Python buffer */
 
     if (reply->depth == 24) {
-        buffer = PyBytes_FromStringAndSize((char*)xcb_get_image_data(reply),
-                                           xcb_get_image_data_length(reply));
+        buffer = PyBytes_FromStringAndSize(
+            (char *)xcb_get_image_data(reply), xcb_get_image_data_length(reply));
     } else {
         PyErr_Format(PyExc_OSError, "unsupported bit depth: %i", reply->depth);
     }
