@@ -85,25 +85,22 @@ point32(Imaging im, int x, int y, int ink) {
 
 static inline void
 point32rgba(Imaging im, int x, int y, int ink) {
-    unsigned int tmp1;
+    unsigned int tmp;
 
     if (x >= 0 && x < im->xsize && y >= 0 && y < im->ysize) {
         UINT8 *out = (UINT8 *)im->image[y] + x * 4;
         UINT8 *in = (UINT8 *)&ink;
-        out[0] = BLEND(in[3], out[0], in[0], tmp1);
-        out[1] = BLEND(in[3], out[1], in[1], tmp1);
-        out[2] = BLEND(in[3], out[2], in[2], tmp1);
+        out[0] = BLEND(in[3], out[0], in[0], tmp);
+        out[1] = BLEND(in[3], out[1], in[1], tmp);
+        out[2] = BLEND(in[3], out[2], in[2], tmp);
     }
 }
 
 static inline void
 hline8(Imaging im, int x0, int y0, int x1, int ink) {
-    int tmp, pixelwidth;
+    int pixelwidth;
 
     if (y0 >= 0 && y0 < im->ysize) {
-        if (x0 > x1) {
-            tmp = x0, x0 = x1, x1 = tmp;
-        }
         if (x0 < 0) {
             x0 = 0;
         } else if (x0 >= im->xsize) {
@@ -126,13 +123,9 @@ hline8(Imaging im, int x0, int y0, int x1, int ink) {
 
 static inline void
 hline32(Imaging im, int x0, int y0, int x1, int ink) {
-    int tmp;
     INT32 *p;
 
     if (y0 >= 0 && y0 < im->ysize) {
-        if (x0 > x1) {
-            tmp = x0, x0 = x1, x1 = tmp;
-        }
         if (x0 < 0) {
             x0 = 0;
         } else if (x0 >= im->xsize) {
@@ -152,13 +145,9 @@ hline32(Imaging im, int x0, int y0, int x1, int ink) {
 
 static inline void
 hline32rgba(Imaging im, int x0, int y0, int x1, int ink) {
-    int tmp;
-    unsigned int tmp1;
+    unsigned int tmp;
 
     if (y0 >= 0 && y0 < im->ysize) {
-        if (x0 > x1) {
-            tmp = x0, x0 = x1, x1 = tmp;
-        }
         if (x0 < 0) {
             x0 = 0;
         } else if (x0 >= im->xsize) {
@@ -173,9 +162,9 @@ hline32rgba(Imaging im, int x0, int y0, int x1, int ink) {
             UINT8 *out = (UINT8 *)im->image[y0] + x0 * 4;
             UINT8 *in = (UINT8 *)&ink;
             while (x0 <= x1) {
-                out[0] = BLEND(in[3], out[0], in[0], tmp1);
-                out[1] = BLEND(in[3], out[1], in[1], tmp1);
-                out[2] = BLEND(in[3], out[2], in[2], tmp1);
+                out[0] = BLEND(in[3], out[0], in[0], tmp);
+                out[1] = BLEND(in[3], out[1], in[1], tmp);
+                out[2] = BLEND(in[3], out[2], in[2], tmp);
                 x0++;
                 out += 4;
             }
@@ -419,7 +408,7 @@ draw_horizontal_lines(
         if (e[i].ymin == y && e[i].ymin == e[i].ymax) {
             int xmax;
             int xmin = e[i].xmin;
-            if (*x_pos < xmin) {
+            if (*x_pos != -1 && *x_pos < xmin) {
                 // Line would be after the current position
                 continue;
             }
@@ -513,7 +502,9 @@ polygon_generic(Imaging im, int n, Edge *e, int ink, int eofill, hline_handler h
                             continue;
                         }
                         // Check if the two edges join to make a corner
-                        if (xx[j-1] == (ymin - other_edge->y0) * other_edge->dx + other_edge->x0) {
+                        if (((ymin == current->ymin && ymin == other_edge->ymin) ||
+                             (ymin == current->ymax && ymin == other_edge->ymax)) &&
+                            xx[j-1] == (ymin - other_edge->y0) * other_edge->dx + other_edge->x0) {
                             // Determine points from the edges on the next row
                             // Or if this is the last row, check the previous row
                             int offset = ymin == ymax ? -1 : 1;
@@ -540,7 +531,7 @@ polygon_generic(Imaging im, int n, Edge *e, int ink, int eofill, hline_handler h
         }
         qsort(xx, j, sizeof(float), x_cmp);
         if (hasAlpha == 1) {
-            int x_pos = 0;
+            int x_pos = j == 0 ? -1 : 0;
             for (i = 1; i < j; i += 2) {
                 int x_end = ROUND_DOWN(xx[i]);
                 if (x_end < x_pos) {
